\name{obliqueshock}
\alias{obliqueshock}

\title{Characteristics of an oblique shock}
\description{Computes the deflecting angle, shock thickness, downstream velocity and downstream momentum flux for an oblique shock as functions of shock angle and Froude number.
}

\usage{ 
obliqueshock(teta,Fr)
}

\arguments{
\item{teta}{shock angle.}
\item{Fr}{Froude number.}
}

\value{\code{obliqueshock} returns a dataframe containing the variables \code{teta} (shock angle), \code{phi} (deflecting angle), \code{delta} (difference between \code{teta} and \code{phi}, \emph{i.e.}\ width of the stream along the deflecting wall), \code{h2ph1} (relative change in flow depth across the shock), \code{u2pu1} (relative change in flow speed across the shock) and \code{h2u2ph1u1} (relative change in momentum flux across the shock). These variables have the same number of elements as \code{teta} or \code{Fr}. The Froude number is returned as the attribute \code{Fr} of the list.
}
\author{Tomas Johannesson}

\examples{
\dontrun{
obliqueshock(22*pi/180,7)
}
}

\note{The angle \code{teta} is given in radians and so are all angles that are returned by the function.

This function returns the theoretically exact oblique shock solution, which represents both the weak and strong shocks, so that the shock angle \code{teta} is a double valued function of the deflecting angle \code{phi}.
}

\seealso{\code{\link{obliquenshock}} and \code{\link{mxphi}}.}

\keyword{math}
